Crate elfo_core

Crate elfo_core 

Re-exports

pub use crate::addr::Addr;
pub use crate::config::Config;
pub use crate::topology::Topology;

Modules

addr
config
Contains useful utilities for working with configuration. The Actoromicon.
coop
Provides a cooperative budget for actors.
dumping
Includes structs and functions to work with dumping. The Actoromicon.
errors
init
logging
messages
remotenetwork and unstable
routers
scope
signal
stream
stuck_detectionunstable-stuck-detection
time
topology
tracing
Includes TraceId and useful utilities around it. The Actoromicon.

Macros

assert_msg
assert_msg_eq
set_protocol
Overrides the protocol name for all messages in the current module. Can be used only once per module. Submodules inherit this override if use super::* is used.

Structs

ActorGroup
ActorMeta
Represents meta information about actor: his group and key.
ActorStartInfo
A struct holding information related to an actor start.
ActorStatus
Represents the current status of an actor. The Actoromicon.
AnyMessage
A heap-allocated message that can be downcasted to a concrete message type.
AnyMessageRef
A reference to the message inside Envelope or AnyMessage.
Blueprint
Context
An actor execution context.
Envelope
An envelope is a wrapper around message with additional metadata, involved in message passing between actors.
Local
Used to send values that cannot be serialized. Works inside the current node only.
MoveOwnership
Used to transfer ownership over messaging.
RequestBuilder
RequestId
ResponseToken
RestartParams
Restart parameters for the backoff strategy when an actor restarts based on the RestartPolicy.
RestartPolicy
The behaviour on actor termination.
TerminationPolicy
The behaviour on the Terminate message.
UnattachedSource
A wrapper to indicate that a source hasn’t been attached to a context yet.

Enums

ActorStartCause
An enum representing various causes for an actor to start.
ActorStatusKind
A list specifying statuses of actors. It’s used with the ActorStatus.

Traits

Message
Represents a message that can be sent between actors and across nodes.
Request
Represents a request that can be sent between actors and across nodes.
SourceHandle
Defines common methods for sources.