NodeNo

Struct NodeNo 

pub struct NodeNo(/* private fields */);
Represents the node’s number in a distributed system. Cannot be 0, it’s reserved to represent the local node.

Nodes with the same node_no cannot be connected.

NOTE: It’s 16-bit unsigned integer, which requires manual management for bigger-than-small clusters and will be replaced with NodeLaunchId totally in the future in order to simplify the management.

Implementations

Source

impl NodeNo

pub const fn from_bits(bits: u16) -> Option<Self>

Available on crate feature unstable only.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub const fn into_bits(self) -> u16

Available on crate feature unstable only.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.