AnyConfig

Struct AnyConfig 

pub struct AnyConfig { /* private fields */ }
Holds user-defined config.

Usually not created directly outside tests sending ValidateConfig or UpdateConfig messages.

Example

In tests it can be used in the following way:

AnyConfig::deserialize(toml! {
    some_param = 10
});

Implementations

Source

impl AnyConfig

pub fn from_value(value: Value) -> Self

Available on crate feature unstable only.

Creates AnyConfig from serde_value::Value.

This method is unstable because it relies on the specific implementation using serde_value. AnyConfig::deserialize should be used instead where possible.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.