Dumper

Struct Dumper 

pub struct Dumper { /* private fields */ }
Available on crate feature unstable only.
Availability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl Dumper

pub fn new(class: &'static str) -> Self

pub fn acquire(&self) -> Option<DumpingPermit<'_>>

Availability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.