pub struct DumpingControl { /* private fields */ }Available on crate feature
unstable only.Expand description
Availability
This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Implementations
Sourceimpl DumpingControl
impl DumpingControl
Sourcepub fn check(&self, class: &'static str) -> CheckResult
pub fn check(&self, class: &'static str) -> CheckResult
Availability
This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.