pub struct Raw<T>(pub T);Available on crate feature
unstable only.Expand description
A wrapper around a raw dump (e.g. received from WS/HTTP).
If the dump is valid JSON, it will be serialized as inner JSON with saving formatting, but without newlines (replaced with a space).
Otherwise, the dump is serialized as JSON string.
Availability
This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Tuple Fields
0: TTrait Implementations