pub struct Timestamp(/* private fields */);Available on crate feature
unstable only.Expand description
Timestamp in nanos since Unix epoch.
Availability
This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.
Implementations