Recorder

Trait Recorder 

pub trait Recorder: Send + Sync {
    // Required methods
    fn enabled(&self) -> bool;
    fn record(&self, dump: Dump);
}
Available on crate feature unstable only.
Availability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Required Methods

fn enabled(&self) -> bool

fn record(&self, dump: Dump)

Implementors