macro_rules! set_protocol {
($protocol:literal) => { ... };
}Expand description
Overrides the protocol name for all messages in the current module.
Can be used only once per module. Submodules inherit this override
if use super::* is used.
macro_rules! set_protocol {
($protocol:literal) => { ... };
}Overrides the protocol name for all messages in the current module.
Can be used only once per module. Submodules inherit this override
if use super::* is used.