pub struct SendNotify { /* private fields */ }Available on crate feature
unstable only.Expand description
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl SendNotify
impl SendNotify
Sourcepub fn notified(&self) -> SendNotified ⓘ
pub fn notified(&self) -> SendNotified ⓘ
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.