node_no

Function node_no 

pub fn node_no() -> NodeNo
Available on crate feature unstable only.
Returns the node number.

Panics

This function will panic if called ouside the actor system.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.