try_node_no

Function try_node_no 

pub fn try_node_no() -> Option<NodeNo>
Available on crate feature unstable only.
Returns the node number if inside the actor system.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.