Scope

Struct Scope 

pub struct Scope { /* private fields */ }

Implementations

Source

impl Scope

pub fn actor(&self) -> Addr

pub fn group(&self) -> Addr

pub fn node_no(&self) -> NodeNo

Available on crate feature unstable only.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn node_launch_id(&self) -> NodeLaunchId

Stability

This API was stabilized in version 0.2.0.

pub fn meta(&self) -> &Arc<ActorMeta>

Returns the current object’s meta.

pub fn trace_id(&self) -> TraceId

Returns the current trace id.

pub fn set_trace_id(&self, trace_id: TraceId)

Replaces the current trace id with the provided one.

pub fn permissions(&self) -> Permissions

Returns the current permissions (for logging, telemetry and so on).

pub async fn within<F: Future>(self, f: F) -> F::Output

Wraps the provided future with the current scope.

pub fn sync_within<R>(self, f: impl FnOnce() -> R) -> R

Runs the provided function with the current scope.