#[non_exhaustive]pub struct ActorStartInfo {
pub cause: ActorStartCause,
}Expand description
A struct holding information related to an actor start.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cause: ActorStartCauseThe cause for the actor start, indicating why the actor is being initialized.