AnyMessageRef

Struct AnyMessageRef 

pub struct AnyMessageRef<'a> { /* private fields */ }
A reference to the message inside Envelope or AnyMessage.

Implementations

Source

impl<'a> AnyMessageRef<'a>

pub fn downcast_ref<M: Message>(&self) -> Option<&'a M>

Methods from Deref<Target = AnyMessage>

pub fn as_ref(&self) -> AnyMessageRef<'_>

Returns AnyMessageRef that borrows the message.

pub fn is<M: Message>(&self) -> bool

Checks if the message is of a specific type.

Note: it returns true if M is AnyMessage.

pub fn downcast_ref<M: Message>(&self) -> Option<&M>

Tries to downcast the message to a reference to the concrete type.

Note: it returns Some(&self) if M is AnyMessage.