Envelope

Struct Envelope 

pub struct Envelope(/* private fields */);
An envelope is a wrapper around message with additional metadata, involved in message passing between actors.

Envelopes aren’t created directly in code, but are produced internally by Context’s methods.

Converting an envelope to a message is usually done by calling the msg! macro, which supports both owned and borrowed usages.

Implementations

Source

impl Envelope

pub fn trace_id(&self) -> TraceId

pub fn message(&self) -> AnyMessageRef<'_>

Returns a reference to the untyped message inside the envelope.

pub fn sender(&self) -> Addr

pub fn request_id(&self) -> Option<RequestId>

pub fn is<M: Message>(&self) -> bool