pub enum ConnectionTo {
Local(Addr),
Remote(String),
}Variants
Implementations
Sourceimpl ConnectionTo
impl ConnectionTo
Sourcepub fn into_remote(self) -> Option<String>
Available on crate feature unstable only.
pub fn into_remote(self) -> Option<String>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.