pub struct RegisterRemoteGroupGuard<'a> { /* private fields */ }Available on crate feature
unstable only.Expand description
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl RegisterRemoteGroupGuard<'_>
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl RegisterRemoteGroupGuard<'_>
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
pub fn handle_addr(&self) -> Addr