#[non_exhaustive]pub struct RemoteActorGroup {
pub name: String,
/* private fields */
}Available on crate feature
unstable only.Expand description
Represents remote group(s).
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringTrait Implementations
Sourceimpl Clone for RemoteActorGroup
impl Clone for RemoteActorGroup
Sourcefn clone(&self) -> RemoteActorGroup
fn clone(&self) -> RemoteActorGroup
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for RemoteActorGroup
impl RefUnwindSafe for RemoteActorGroup
impl Send for RemoteActorGroup
impl Sync for RemoteActorGroup
impl Unpin for RemoteActorGroup
impl UnsafeUnpin for RemoteActorGroup
impl UnwindSafe for RemoteActorGroup