SourceHandle

Trait SourceHandle 

pub trait SourceHandle: Sealed {
    // Required methods
    fn is_terminated(&self) -> bool;
    fn terminate_by_ref(&self) -> bool;

    // Provided method
    fn terminate(self) -> bool
       where Self: Sized { ... }
}
Defines common methods for sources.

Required Methods

fn is_terminated(&self) -> bool

Returns true if the source has stopped producing messages.

fn terminate_by_ref(&self) -> bool

Terminates the source. Drop is called immediately.

Returns true if the source was terminated by this call, or false if it was already terminated.

Provided Methods

fn terminate(self) -> bool
where Self: Sized,

Terminates the source. Drop is called immediately.

Returns true if the source was terminated by this call, or false if it was already terminated.

Implementors