Re-exports
Modules
- addr
- config
- Contains useful utilities for working with configuration. The Actoromicon.
- coop
- Provides a cooperative budget for actors.
- dumping
- Includes structs and functions to work with dumping. The Actoromicon.
- errors
- init
- logging
- messages
- remote
networkandunstable - routers
- scope
- signal
- stream
- stuck_
detection unstable-stuck-detection - time
- topology
- tracing
- Includes
TraceIdand useful utilities around it. The Actoromicon.
Macros
- assert_
msg - assert_
msg_ eq - set_
protocol - Overrides the protocol name for all messages in the current module.
Can be used only once per module. Submodules inherit this override
if
use super::*is used.
Structs
- Actor
Group - Actor
Meta - Represents meta information about actor: his group and key.
- Actor
Start Info - A struct holding information related to an actor start.
- Actor
Status - Represents the current status of an actor. The Actoromicon.
- AnyMessage
- A heap-allocated message that can be downcasted to a concrete message type.
- AnyMessage
Ref - A reference to the message inside
EnvelopeorAnyMessage. - Blueprint
- Context
- An actor execution context.
- Envelope
- An envelope is a wrapper around message with additional metadata, involved in message passing between actors.
- Local
- Used to send values that cannot be serialized. Works inside the current node only.
- Move
Ownership - Used to transfer ownership over messaging.
- Request
Builder - Request
Id - Response
Token - Restart
Params - Restart parameters for the backoff strategy when an actor restarts based on the RestartPolicy.
- Restart
Policy - The behaviour on actor termination.
- Termination
Policy - The behaviour on the
Terminatemessage. - Unattached
Source - A wrapper to indicate that a source hasn’t been attached to a context yet.
Enums
- Actor
Start Cause - An enum representing various causes for an actor to start.
- Actor
Status Kind - A list specifying statuses of actors. It’s used with the
ActorStatus.
Traits
- Message
- Represents a message that can be sent between actors and across nodes.
- Request
- Represents a request that can be sent between actors and across nodes.
- Source
Handle - Defines common methods for sources.