pub struct Dumper { /* private fields */ }Available on crate feature
unstable only.Expand description
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl Dumper
impl Dumper
Sourcepub fn new(class: &'static str) -> Self
pub fn new(class: &'static str) -> Self
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn acquire(&self) -> Option<DumpingPermit<'_>>
pub fn acquire(&self) -> Option<DumpingPermit<'_>>
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.