pub fn node_no() -> NodeNo
unstable
Returns the node number.
This function will panic if called ouside the actor system.
This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.