pub struct Envelope(/* private fields */);Expand description
An envelope is a wrapper around message with additional metadata, involved in message passing between actors.
Envelopes aren’t created directly in code, but are produced internally
by Context’s methods.
Converting an envelope to a message is usually done by calling the msg!
macro, which supports both owned and borrowed usages.
Implementations