pub struct Delay<M> { /* private fields */ }Expand description
A source that emits a message after some specified time.
Tracing
The emitted message continues the current trace.
Example
use elfo::time::Delay;
#[message]
struct MyTick;
while let Some(envelope) = ctx.recv().await {
msg!(match envelope {
SomeEvent => {
ctx.attach(Delay::new(ctx.config().delay, MyTick));
},
MyTick => {
tracing::info!("tick!");
},
});
}Implementations
Sourceimpl<M: Message> Delay<M>
impl<M: Message> Delay<M>
Sourcepub fn new(delay: Duration, message: M) -> UnattachedSource<Self>
pub fn new(delay: Duration, message: M) -> UnattachedSource<Self>
Schedules the timer to emit the provided message after delay.
Creates an unattached instance of Delay.
Sourcepub fn until(when: Instant, message: M) -> UnattachedSource<Self>
Available on crate feature unstable only.
pub fn until(when: Instant, message: M) -> UnattachedSource<Self>
unstable only.Schedules the timer to emit the provided message at when.
Creates an unattached instance of Delay.
Stability
This method is unstable, because it accepts tokio::time::Instant,
which will be replaced in the future to support other runtimes.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.