pub struct Local<'t> { /* private fields */ }Expand description
Represents a local group’s settings.
Implementations
Sourceimpl Local<'_>
impl Local<'_>
Sourcepub fn entrypoint(self) -> Self
pub fn entrypoint(self) -> Self
Mark this group as an entrypoint.
It means, that this group will be started automatically when the system starts, with empty configuration is provided.
Usually, only system.configurers group is marked as an entrypoint.
Sourcepub fn route_to<F>(&self, dest: &impl Destination<F>, filter: F)
pub fn route_to<F>(&self, dest: &impl Destination<F>, filter: F)
Defines a route to the given destination (local or remote group).
Examples
Local to local:
use elfo::{Topology, msg};
let topology = Topology::empty();
let foo = topology.local("foo");
let bar = topology.local("bar");
foo.route_to(&bar, |envelope| {
msg!(match envelope {
SomeEvent => true,
_ => false,
})
});Local to remote (requires the network feature): TODO
pub fn route_all_to(&self, dest: &Local<'_>)